import { IListLevelProperties } from './IListLevelProperties';
/**
 * This class represents a list style where list items are preceded by bullets.
 *
 * @example
 * document.getStyleManager()
 *   .createListStyle('Contents')
 *   .createBulletListLevelStyle(3);
 *
 * @since 0.11.0
 */
export declare class BulletListLevelStyle implements IListLevelProperties {
    private bulletChar;
    private bulletRelativeSize;
    private level;
    private numPrefix;
    private numSuffix;
    private listLevelProperties;
    /**
     * Creates a `BulletListLevelStyle` instance that represents a list style where list items are preceded by bullets.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     *
     * @param {number} level The level of the list style, starting with `1`
     *
     * @since 0.11.0
     */
    constructor(level: number);
    /**
     * The `getBulletChar()` method returns the character to use as the bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getBulletChar();    // '\u2022'
     * style.setBulletChar('~');
     * style.getBulletChar();    // '~'
     *
     * @returns {string} The character to use as the bullet
     * @since 0.11.0
     */
    getBulletChar(): string;
    /**
     * The `setBulletChar()` method sets the character to use as the bullet.
     *
     * If an illegal value is provided, the value will be ignored.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setBulletChar('~'); // '~'
     * style.setBulletChar('');  // '~'
     *
     * @param {string} bulletChar The character to use as the bullet
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setBulletChar(bulletChar: string): BulletListLevelStyle;
    /**
     * The `getLevel()` method returns the level of the list style.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getLevel(); // 3
     *
     * @returns {number} The level of the list style, starting with `1`
     * @since 0.11.0
     */
    getLevel(): number;
    /**
     * The `getNumberPrefix()` method returns the character to display before a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getNumberPrefix();    // undefined
     * style.setNumberPrefix('~');
     * style.getNumberPrefix();    // '~'
     *
     * @returns {string | undefined} The character to display before a bullet or `undefined` if no prefix is set
     * @since 0.11.0
     */
    getNumberPrefix(): string | undefined;
    /**
     * The `setNumberPrefix()` method sets the character to display before a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setNumberPrefix('~');       // '~'
     * style.setNumberPrefix(undefined); // undefined
     *
     * @param {string | undefined} prefix The character to display before a bullet or `undefined` to unset the prefix
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setNumberPrefix(prefix: string | undefined): this;
    /**
     * The `getNumberSuffix()` method returns the character to display after a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getNumberSuffix();    // undefined
     * style.setNumberSuffix('~');
     * style.getNumberSuffix();    // '~'
     *
     * @returns {string | undefined} The character to display after a bullet or `undefined` if no suffix is set
     * @since 0.11.0
     */
    getNumberSuffix(): string | undefined;
    /**
     * The `setNumberSuffix()` method sets the character to display after a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setNumberSuffix('~');       // '~'
     * style.setNumberSuffix(undefined); // undefined
     *
     * @param {string | undefined} suffix The character to display after a bullet or `undefined` to unset the suffix
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setNumberSuffix(suffix: string | undefined): this;
    /**
     * The `getRelativeBulletSize()` method returns the percentage value for the bullet size relative to the font size of the paragraphs in the bullet list.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getRelativeBulletSize();      // undefined
     * style.setRelativeBulletSize('23%');
     * style.getRelativeBulletSize();      // '23%'
     *
     * @returns {string | undefined} The percentage value for the bullet size or `undefined` if no relative bullet size is set
     * @since 0.11.0
     */
    getRelativeBulletSize(): string | undefined;
    /**
     * The `setNumberSuffix()` method sets the percentage value for the bullet size relative to the font size of the paragraphs in the bullet list.
     *
     * If an illegal value is provided, the value will be ignored.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setRelativeBulletSize('23%');     // '23%'
     * style.setRelativeBulletSize('42px');    // '23%'
     * style.setRelativeBulletSize(undefined); // undefined
     *
     * @param {string | undefined} relativeSize The percentage value for the bullet size or `undefined` to unset the bullet size
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setRelativeBulletSize(relativeSize: string | undefined): BulletListLevelStyle;
    /** @inheritdoc */
    getListLevelPositionAndSpaceMode(): string;
    /** @inheritdoc */
    getLabelFollowedBy(): string;
    /** @inheritdoc */
    setLabelFollowedBy(value: 'listtab' | 'space' | 'nothing'): this;
    /** @inheritdoc */
    getListTabStopPosition(): number | undefined;
    /** @inheritdoc */
    setListTabStopPosition(position: number | undefined): this;
    /** @inheritdoc */
    getTextIndent(): number | undefined;
    /** @inheritdoc */
    setTextIndent(indent: number | undefined): this;
    /** @inheritdoc */
    getMarginLeft(): number | undefined;
    /** @inheritdoc */
    setMarginLeft(margin: number | undefined): this;
}
