import { BulletListLevelStyle } from './BulletListLevelStyle';
import { Style } from './Style';
/**
 * This class represents a list style.
 *
 * List styles are used to specify the formatting of a list and its items.
 * A list style contains a set of style elements for each list level (@see ListLevelStyle).
 * If a list style is applied to a list but does not contain a list level specification for a specific level, the list level style of the next lower level is used.
 *
 * @example
 * document.getStyleManager().createListStyle('Contents');
 * document.getBody()
 *   .addList()
 *   .setStyleName('Contents);
 *
 * @since 0.11.0
 */
export declare class ListStyle extends Style {
    private isConsecutiveNumbering;
    private listLevelStyles;
    /**
     * Creates a `ListStyle` instance that represents the formatting of a list.
     *
     * @example
     * const style = new ListStyle('Contents');
     *
     * @param {string} displayName The unique display name for the style
     *
     * @since 0.11.0
     */
    constructor(displayName?: string);
    /**
     * The `getConsecutiveNumbering()` method returns whether the style uses consecutive numbering for all list levels or whether each list level restarts the numbering.
     *
     * @example
     * const style = new ListStyle('Contents');
     * style.getConsecutiveNumbering();     // false
     * style.setConsecutiveNumbering(true);
     * style.getConsecutiveNumbering();     // true
     *
     * @returns {boolean} `true` if consecutive numbering is used for all list levels or `false` if each list level restarts numbering
     * @since 0.11.0
     */
    getConsecutiveNumbering(): boolean;
    /**
     * The `setConsecutiveNumbering()` method sets returns whether the style uses consecutive numbering for all list levels or whether each list level restarts the numbering.
     *
     * @example
     * const style = new ListStyle('Contents');
     * style.setConsecutiveNumbering(true); // true
     *
     * @param {boolean} consecutiveNumbering `true` if consecutive numbering is used for all list levels or `false` if each list level restarts numbering
     * @returns {ListStyle} The `ListStyle` object
     * @since 0.11.0
     */
    setConsecutiveNumbering(consecutiveNumbering: boolean): ListStyle;
    /**
     * The `createBulletListLevelStyle()` method creates a new `BulletListLevelStyle` instance for the given list level.
     * If a list level style for this level already exists, the existing style will be overwritten.
     *
     * @example
     * const style = new ListStyle('Contents');
     * style.createBulletListLevelStyle(3);
     *
     * @param {number} level The level of the list style, starting with `1`
     * @returns {BulletListLevelStyle} A new `BulletListLevelStyle` instance with the specified level
     * @throws {Error} if the given list level is invalid
     * @since 0.11.0
     */
    createBulletListLevelStyle(level: number): BulletListLevelStyle;
    /**
     * The `getListLevelStyle()` method returns the list level style for the given list level.
     * If a list level style for this level already exists, the existing style will be overwritten.
     *
     * @example
     * const style = new ListStyle('Contents');
     * style.getListLevelStyle(3);
     *
     * @param {number} level The level of the list style, starting with `1`
     * @returns {BulletListLevelStyle | undefined} The list level style for the specified level or `undefined` if no list level style is defined for the specified level
     * @since 0.11.0
     */
    getListLevelStyle(level: number): BulletListLevelStyle | undefined;
    /**
     * The `getListLevelStyles()` method returns a new `Array` object that contains all list level styles of a list style.
     *
     * @example
     * const style = new ListStyle('Contents');
     * style.createBulletListLevelStyle(1);
     * style.createBulletListLevelStyle(2);
     * styles.getListLevelStyles();
     *
     * @returns {BulletListLevelStyle[]} A new `Array` object that contains the list level styles of a list style
     * @since 0.11.0
     */
    getListLevelStyles(): BulletListLevelStyle[];
    /**
     * The `removeListLevelStyle()` method removes the list level style for the given list level.
     *
     * @example
     * const style = new ListStyle('Contents');
     * style.createBulletListLevelStyle(3);
     * style.removeListLevelStyle(3);
     * styles.getListLevelStyles();             // []
     *
     * @param {number} level The level of the list style, starting with `1`
     * @returns {ListStyle} The `ListStyle` object
     * @since 0.11.0
     */
    removeListLevelStyle(level: number): ListStyle;
}
