"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetaWriter = void 0;
const OdfElementName_1 = require("../OdfElementName");
const MetaElementName_1 = require("./MetaElementName");
/**
 * Transforms a {@link Meta} object into ODF conform XML
 *
 * @since 0.7.0
 */
class MetaWriter {
    /**
     * Transforms the given {@link Meta} into Open Document Format.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node in the DOM
     * @param {Meta} meta The Meta to serialize
     * @since 0.7.0
     */
    write(document, root, meta) {
        const metaElement = document.createElement(OdfElementName_1.OdfElementName.OfficeMeta);
        root.appendChild(metaElement);
        this.setGeneratorElement(document, metaElement, meta);
        this.setTitleElement(document, metaElement, meta);
        this.setDescriptionElement(document, metaElement, meta);
        this.setSubjectElement(document, metaElement, meta);
        this.setKeywordElements(document, metaElement, meta);
        this.setInitialCreatorElement(document, metaElement, meta);
        this.setCreatorElement(document, metaElement, meta);
        this.setPrintedByElement(document, metaElement, meta);
        this.setCreationDateElement(document, metaElement, meta);
        this.setDateElement(document, metaElement, meta);
        this.setPrintDateElement(document, metaElement, meta);
        this.setLanguageElement(document, metaElement, meta);
        this.setEditingCyclesElement(document, metaElement, meta);
    }
    /**
     * Sets the `meta:creation-date` element to the date and time this class was constructed.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setCreationDateElement(document, metaElement, meta) {
        const creationDateElement = document.createElement(MetaElementName_1.MetaElementName.MetaCreationDate);
        metaElement.appendChild(creationDateElement);
        creationDateElement.appendChild(document.createTextNode(meta.getCreationDate().toISOString()));
    }
    /**
     * Sets the `dc:creator` element if creator is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setCreatorElement(document, metaElement, meta) {
        const creator = meta.getCreator();
        if (creator === undefined || creator.length === 0) {
            return;
        }
        const creatorElement = document.createElement(MetaElementName_1.MetaElementName.DcCreator);
        metaElement.appendChild(creatorElement);
        creatorElement.appendChild(document.createTextNode(creator));
    }
    /**
     * Sets the `dc:date` element if date is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setDateElement(document, metaElement, meta) {
        const date = meta.getDate();
        if (date === undefined) {
            return;
        }
        const dateElement = document.createElement(MetaElementName_1.MetaElementName.DcDate);
        metaElement.appendChild(dateElement);
        dateElement.appendChild(document.createTextNode(date.toISOString()));
    }
    /**
     * Sets the `dc:description` element if description is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setDescriptionElement(document, metaElement, meta) {
        const description = meta.getDescription();
        if (description === undefined || description.length === 0) {
            return;
        }
        const descriptionElement = document.createElement(MetaElementName_1.MetaElementName.DcDescription);
        metaElement.appendChild(descriptionElement);
        descriptionElement.appendChild(document.createTextNode(description));
    }
    /**
     * Sets the `meta:editing-cycles` element to 1.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setEditingCyclesElement(document, metaElement, meta) {
        const editingCyclesElement = document.createElement(MetaElementName_1.MetaElementName.MetaEditingCycles);
        metaElement.appendChild(editingCyclesElement);
        editingCyclesElement.appendChild(document.createTextNode(meta.getEditingCycles().toString()));
    }
    /**
     * Sets the `meta:generator` element to the name and version of this library (`simple-odf/x.y.z`).
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setGeneratorElement(document, metaElement, meta) {
        const generatorElement = document.createElement(MetaElementName_1.MetaElementName.MetaGenerator);
        metaElement.appendChild(generatorElement);
        generatorElement.appendChild(document.createTextNode(meta.getGenerator()));
    }
    /**
     * Sets the `meta:initial-creator` element to the current user.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setInitialCreatorElement(document, metaElement, meta) {
        const initialCreator = meta.getInitialCreator();
        if (initialCreator === undefined || initialCreator.length === 0) {
            return;
        }
        const creatorElement = document.createElement(MetaElementName_1.MetaElementName.MetaInitialCreator);
        metaElement.appendChild(creatorElement);
        creatorElement.appendChild(document.createTextNode(initialCreator));
    }
    /**
     * Sets the `meta:keyword` elements if any keyword is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setKeywordElements(document, metaElement, meta) {
        meta.getKeywords().forEach((keyword) => {
            const subjectElement = document.createElement(MetaElementName_1.MetaElementName.MetaKeyword);
            metaElement.appendChild(subjectElement);
            subjectElement.appendChild(document.createTextNode(keyword));
        });
    }
    /**
     * Sets the `dc:language` element if language is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setLanguageElement(document, metaElement, meta) {
        const language = meta.getLanguage();
        if (language === undefined || language.length === 0) {
            return;
        }
        const languageElement = document.createElement(MetaElementName_1.MetaElementName.DcLanguage);
        metaElement.appendChild(languageElement);
        languageElement.appendChild(document.createTextNode(language));
    }
    /**
     * Sets the `meta:print-date` element if print date is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setPrintDateElement(document, metaElement, meta) {
        const printDate = meta.getPrintDate();
        if (printDate === undefined) {
            return;
        }
        const printDateElement = document.createElement(MetaElementName_1.MetaElementName.MetaPrintDate);
        metaElement.appendChild(printDateElement);
        printDateElement.appendChild(document.createTextNode(printDate.toISOString()));
    }
    /**
     * Sets the `meta:printed-by` element if printing name is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setPrintedByElement(document, metaElement, meta) {
        const printedBy = meta.getPrintedBy();
        if (printedBy === undefined || printedBy.length === 0) {
            return;
        }
        const printedByElement = document.createElement(MetaElementName_1.MetaElementName.MetaPrintedBy);
        metaElement.appendChild(printedByElement);
        printedByElement.appendChild(document.createTextNode(printedBy));
    }
    /**
     * Sets the `dc:subject` element if subject is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setSubjectElement(document, metaElement, meta) {
        const subject = meta.getSubject();
        if (subject === undefined || subject.length === 0) {
            return;
        }
        const subjectElement = document.createElement(MetaElementName_1.MetaElementName.DcSubject);
        metaElement.appendChild(subjectElement);
        subjectElement.appendChild(document.createTextNode(subject));
    }
    /**
     * Sets the `dc:title` element if title is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    setTitleElement(document, metaElement, meta) {
        const title = meta.getTitle();
        if (title === undefined || title.length === 0) {
            return;
        }
        const titleElement = document.createElement(MetaElementName_1.MetaElementName.DcTitle);
        metaElement.appendChild(titleElement);
        titleElement.appendChild(document.createTextNode(title));
    }
}
exports.MetaWriter = MetaWriter;
